# pulpcore_client

PulpcoreClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 3.49.6
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulpcore_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulpcore_client-3.49.6.gem
```

(for development, run `gem install --dev ./pulpcore_client-3.49.6.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulpcore_client', '~> 3.49.6'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulpcore_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulpcore_client'

# Setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
opts = {
  customized: true, # Boolean | Filter results where customized matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `creation_hooks` - Creation hooks * `-creation_hooks` - Creation hooks (descending) * `statements` - Statements * `-statements` - Statements (descending) * `viewset_name` - Viewset name * `-viewset_name` - Viewset name (descending) * `customized` - Customized * `-customized` - Customized (descending) * `queryset_scoping` - Queryset scoping * `-queryset_scoping` - Queryset scoping (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  viewset_name: 'viewset_name_example', # String | Filter results where viewset_name matches value
  viewset_name__contains: 'viewset_name__contains_example', # String | Filter results where viewset_name contains value
  viewset_name__icontains: 'viewset_name__icontains_example', # String | Filter results where viewset_name contains value
  viewset_name__iexact: 'viewset_name__iexact_example', # String | Filter results where viewset_name matches value
  viewset_name__in: ['viewset_name__in_example'], # Array<String> | Filter results where viewset_name is in a comma-separated list of values
  viewset_name__iregex: 'viewset_name__iregex_example', # String | Filter results where viewset_name matches regex value
  viewset_name__istartswith: 'viewset_name__istartswith_example', # String | Filter results where viewset_name starts with value
  viewset_name__regex: 'viewset_name__regex_example', # String | Filter results where viewset_name matches regex value
  viewset_name__startswith: 'viewset_name__startswith_example', # String | Filter results where viewset_name starts with value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List access policys
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpcoreClient::AccessPoliciesApi* | [**list**](docs/AccessPoliciesApi.md#list) | **GET** /pulp/api/v3/access_policies/ | List access policys
*PulpcoreClient::AccessPoliciesApi* | [**partial_update**](docs/AccessPoliciesApi.md#partial_update) | **PATCH** {access_policy_href} | Update an access policy
*PulpcoreClient::AccessPoliciesApi* | [**read**](docs/AccessPoliciesApi.md#read) | **GET** {access_policy_href} | Inspect an access policy
*PulpcoreClient::AccessPoliciesApi* | [**reset**](docs/AccessPoliciesApi.md#reset) | **POST** {access_policy_href}reset/ | 
*PulpcoreClient::AccessPoliciesApi* | [**update**](docs/AccessPoliciesApi.md#update) | **PUT** {access_policy_href} | Update an access policy
*PulpcoreClient::ArtifactsApi* | [**create**](docs/ArtifactsApi.md#create) | **POST** /pulp/api/v3/artifacts/ | Create an artifact
*PulpcoreClient::ArtifactsApi* | [**delete**](docs/ArtifactsApi.md#delete) | **DELETE** {artifact_href} | Delete an artifact
*PulpcoreClient::ArtifactsApi* | [**list**](docs/ArtifactsApi.md#list) | **GET** /pulp/api/v3/artifacts/ | List artifacts
*PulpcoreClient::ArtifactsApi* | [**read**](docs/ArtifactsApi.md#read) | **GET** {artifact_href} | Inspect an artifact
*PulpcoreClient::ContentApi* | [**list**](docs/ContentApi.md#list) | **GET** /pulp/api/v3/content/ | List content
*PulpcoreClient::ContentguardsApi* | [**list**](docs/ContentguardsApi.md#list) | **GET** /pulp/api/v3/contentguards/ | List content guards
*PulpcoreClient::ContentguardsCompositeApi* | [**add_role**](docs/ContentguardsCompositeApi.md#add_role) | **POST** {composite_content_guard_href}add_role/ | Add a role
*PulpcoreClient::ContentguardsCompositeApi* | [**create**](docs/ContentguardsCompositeApi.md#create) | **POST** /pulp/api/v3/contentguards/core/composite/ | Create a composite content guard
*PulpcoreClient::ContentguardsCompositeApi* | [**delete**](docs/ContentguardsCompositeApi.md#delete) | **DELETE** {composite_content_guard_href} | Delete a composite content guard
*PulpcoreClient::ContentguardsCompositeApi* | [**list**](docs/ContentguardsCompositeApi.md#list) | **GET** /pulp/api/v3/contentguards/core/composite/ | List composite content guards
*PulpcoreClient::ContentguardsCompositeApi* | [**list_roles**](docs/ContentguardsCompositeApi.md#list_roles) | **GET** {composite_content_guard_href}list_roles/ | List roles
*PulpcoreClient::ContentguardsCompositeApi* | [**my_permissions**](docs/ContentguardsCompositeApi.md#my_permissions) | **GET** {composite_content_guard_href}my_permissions/ | List user permissions
*PulpcoreClient::ContentguardsCompositeApi* | [**partial_update**](docs/ContentguardsCompositeApi.md#partial_update) | **PATCH** {composite_content_guard_href} | Update a composite content guard
*PulpcoreClient::ContentguardsCompositeApi* | [**read**](docs/ContentguardsCompositeApi.md#read) | **GET** {composite_content_guard_href} | Inspect a composite content guard
*PulpcoreClient::ContentguardsCompositeApi* | [**remove_role**](docs/ContentguardsCompositeApi.md#remove_role) | **POST** {composite_content_guard_href}remove_role/ | Remove a role
*PulpcoreClient::ContentguardsCompositeApi* | [**update**](docs/ContentguardsCompositeApi.md#update) | **PUT** {composite_content_guard_href} | Update a composite content guard
*PulpcoreClient::ContentguardsContentRedirectApi* | [**add_role**](docs/ContentguardsContentRedirectApi.md#add_role) | **POST** {content_redirect_content_guard_href}add_role/ | Add a role
*PulpcoreClient::ContentguardsContentRedirectApi* | [**create**](docs/ContentguardsContentRedirectApi.md#create) | **POST** /pulp/api/v3/contentguards/core/content_redirect/ | Create a content redirect content guard
*PulpcoreClient::ContentguardsContentRedirectApi* | [**delete**](docs/ContentguardsContentRedirectApi.md#delete) | **DELETE** {content_redirect_content_guard_href} | Delete a content redirect content guard
*PulpcoreClient::ContentguardsContentRedirectApi* | [**list**](docs/ContentguardsContentRedirectApi.md#list) | **GET** /pulp/api/v3/contentguards/core/content_redirect/ | List content redirect content guards
*PulpcoreClient::ContentguardsContentRedirectApi* | [**list_roles**](docs/ContentguardsContentRedirectApi.md#list_roles) | **GET** {content_redirect_content_guard_href}list_roles/ | List roles
*PulpcoreClient::ContentguardsContentRedirectApi* | [**my_permissions**](docs/ContentguardsContentRedirectApi.md#my_permissions) | **GET** {content_redirect_content_guard_href}my_permissions/ | List user permissions
*PulpcoreClient::ContentguardsContentRedirectApi* | [**partial_update**](docs/ContentguardsContentRedirectApi.md#partial_update) | **PATCH** {content_redirect_content_guard_href} | Update a content redirect content guard
*PulpcoreClient::ContentguardsContentRedirectApi* | [**read**](docs/ContentguardsContentRedirectApi.md#read) | **GET** {content_redirect_content_guard_href} | Inspect a content redirect content guard
*PulpcoreClient::ContentguardsContentRedirectApi* | [**remove_role**](docs/ContentguardsContentRedirectApi.md#remove_role) | **POST** {content_redirect_content_guard_href}remove_role/ | Remove a role
*PulpcoreClient::ContentguardsContentRedirectApi* | [**update**](docs/ContentguardsContentRedirectApi.md#update) | **PUT** {content_redirect_content_guard_href} | Update a content redirect content guard
*PulpcoreClient::ContentguardsHeaderApi* | [**add_role**](docs/ContentguardsHeaderApi.md#add_role) | **POST** {header_content_guard_href}add_role/ | Add a role
*PulpcoreClient::ContentguardsHeaderApi* | [**create**](docs/ContentguardsHeaderApi.md#create) | **POST** /pulp/api/v3/contentguards/core/header/ | Create a header content guard
*PulpcoreClient::ContentguardsHeaderApi* | [**delete**](docs/ContentguardsHeaderApi.md#delete) | **DELETE** {header_content_guard_href} | Delete a header content guard
*PulpcoreClient::ContentguardsHeaderApi* | [**list**](docs/ContentguardsHeaderApi.md#list) | **GET** /pulp/api/v3/contentguards/core/header/ | List header content guards
*PulpcoreClient::ContentguardsHeaderApi* | [**list_roles**](docs/ContentguardsHeaderApi.md#list_roles) | **GET** {header_content_guard_href}list_roles/ | List roles
*PulpcoreClient::ContentguardsHeaderApi* | [**my_permissions**](docs/ContentguardsHeaderApi.md#my_permissions) | **GET** {header_content_guard_href}my_permissions/ | List user permissions
*PulpcoreClient::ContentguardsHeaderApi* | [**partial_update**](docs/ContentguardsHeaderApi.md#partial_update) | **PATCH** {header_content_guard_href} | Update a header content guard
*PulpcoreClient::ContentguardsHeaderApi* | [**read**](docs/ContentguardsHeaderApi.md#read) | **GET** {header_content_guard_href} | Inspect a header content guard
*PulpcoreClient::ContentguardsHeaderApi* | [**remove_role**](docs/ContentguardsHeaderApi.md#remove_role) | **POST** {header_content_guard_href}remove_role/ | Remove a role
*PulpcoreClient::ContentguardsHeaderApi* | [**update**](docs/ContentguardsHeaderApi.md#update) | **PUT** {header_content_guard_href} | Update a header content guard
*PulpcoreClient::ContentguardsRbacApi* | [**add_role**](docs/ContentguardsRbacApi.md#add_role) | **POST** {r_b_a_c_content_guard_href}add_role/ | Add a role
*PulpcoreClient::ContentguardsRbacApi* | [**create**](docs/ContentguardsRbacApi.md#create) | **POST** /pulp/api/v3/contentguards/core/rbac/ | Create a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**delete**](docs/ContentguardsRbacApi.md#delete) | **DELETE** {r_b_a_c_content_guard_href} | Delete a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**list**](docs/ContentguardsRbacApi.md#list) | **GET** /pulp/api/v3/contentguards/core/rbac/ | List rbac content guards
*PulpcoreClient::ContentguardsRbacApi* | [**list_roles**](docs/ContentguardsRbacApi.md#list_roles) | **GET** {r_b_a_c_content_guard_href}list_roles/ | List roles
*PulpcoreClient::ContentguardsRbacApi* | [**my_permissions**](docs/ContentguardsRbacApi.md#my_permissions) | **GET** {r_b_a_c_content_guard_href}my_permissions/ | List user permissions
*PulpcoreClient::ContentguardsRbacApi* | [**partial_update**](docs/ContentguardsRbacApi.md#partial_update) | **PATCH** {r_b_a_c_content_guard_href} | Update a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**read**](docs/ContentguardsRbacApi.md#read) | **GET** {r_b_a_c_content_guard_href} | Inspect a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**remove_role**](docs/ContentguardsRbacApi.md#remove_role) | **POST** {r_b_a_c_content_guard_href}remove_role/ | Remove a role
*PulpcoreClient::ContentguardsRbacApi* | [**update**](docs/ContentguardsRbacApi.md#update) | **PUT** {r_b_a_c_content_guard_href} | Update a rbac content guard
*PulpcoreClient::DistributionsApi* | [**list**](docs/DistributionsApi.md#list) | **GET** /pulp/api/v3/distributions/ | List distributions
*PulpcoreClient::DistributionsArtifactsApi* | [**list**](docs/DistributionsArtifactsApi.md#list) | **GET** /pulp/api/v3/distributions/core/artifacts/ | List artifact distributions
*PulpcoreClient::DistributionsArtifactsApi* | [**read**](docs/DistributionsArtifactsApi.md#read) | **GET** {artifact_distribution_href} | Inspect an artifact distribution
*PulpcoreClient::DomainsApi* | [**create**](docs/DomainsApi.md#create) | **POST** /pulp/api/v3/domains/ | Create a domain
*PulpcoreClient::DomainsApi* | [**delete**](docs/DomainsApi.md#delete) | **DELETE** {domain_href} | Delete a domain
*PulpcoreClient::DomainsApi* | [**list**](docs/DomainsApi.md#list) | **GET** /pulp/api/v3/domains/ | List domains
*PulpcoreClient::DomainsApi* | [**partial_update**](docs/DomainsApi.md#partial_update) | **PATCH** {domain_href} | Update a domain
*PulpcoreClient::DomainsApi* | [**read**](docs/DomainsApi.md#read) | **GET** {domain_href} | Inspect a domain
*PulpcoreClient::DomainsApi* | [**update**](docs/DomainsApi.md#update) | **PUT** {domain_href} | Update a domain
*PulpcoreClient::ExportersFilesystemApi* | [**create**](docs/ExportersFilesystemApi.md#create) | **POST** /pulp/api/v3/exporters/core/filesystem/ | Create a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**delete**](docs/ExportersFilesystemApi.md#delete) | **DELETE** {filesystem_exporter_href} | Delete a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**list**](docs/ExportersFilesystemApi.md#list) | **GET** /pulp/api/v3/exporters/core/filesystem/ | List filesystem exporters
*PulpcoreClient::ExportersFilesystemApi* | [**partial_update**](docs/ExportersFilesystemApi.md#partial_update) | **PATCH** {filesystem_exporter_href} | Update a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**read**](docs/ExportersFilesystemApi.md#read) | **GET** {filesystem_exporter_href} | Inspect a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**update**](docs/ExportersFilesystemApi.md#update) | **PUT** {filesystem_exporter_href} | Update a filesystem exporter
*PulpcoreClient::ExportersFilesystemExportsApi* | [**create**](docs/ExportersFilesystemExportsApi.md#create) | **POST** {filesystem_exporter_href}exports/ | Create a filesystem export
*PulpcoreClient::ExportersFilesystemExportsApi* | [**delete**](docs/ExportersFilesystemExportsApi.md#delete) | **DELETE** {filesystem_filesystem_export_href} | Delete a filesystem export
*PulpcoreClient::ExportersFilesystemExportsApi* | [**list**](docs/ExportersFilesystemExportsApi.md#list) | **GET** {filesystem_exporter_href}exports/ | List filesystem exports
*PulpcoreClient::ExportersFilesystemExportsApi* | [**read**](docs/ExportersFilesystemExportsApi.md#read) | **GET** {filesystem_filesystem_export_href} | Inspect a filesystem export
*PulpcoreClient::ExportersPulpApi* | [**create**](docs/ExportersPulpApi.md#create) | **POST** /pulp/api/v3/exporters/core/pulp/ | Create a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**delete**](docs/ExportersPulpApi.md#delete) | **DELETE** {pulp_exporter_href} | Delete a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**list**](docs/ExportersPulpApi.md#list) | **GET** /pulp/api/v3/exporters/core/pulp/ | List pulp exporters
*PulpcoreClient::ExportersPulpApi* | [**partial_update**](docs/ExportersPulpApi.md#partial_update) | **PATCH** {pulp_exporter_href} | Update a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**read**](docs/ExportersPulpApi.md#read) | **GET** {pulp_exporter_href} | Inspect a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**update**](docs/ExportersPulpApi.md#update) | **PUT** {pulp_exporter_href} | Update a pulp exporter
*PulpcoreClient::ExportersPulpExportsApi* | [**create**](docs/ExportersPulpExportsApi.md#create) | **POST** {pulp_exporter_href}exports/ | Create a pulp export
*PulpcoreClient::ExportersPulpExportsApi* | [**delete**](docs/ExportersPulpExportsApi.md#delete) | **DELETE** {pulp_pulp_export_href} | Delete a pulp export
*PulpcoreClient::ExportersPulpExportsApi* | [**list**](docs/ExportersPulpExportsApi.md#list) | **GET** {pulp_exporter_href}exports/ | List pulp exports
*PulpcoreClient::ExportersPulpExportsApi* | [**read**](docs/ExportersPulpExportsApi.md#read) | **GET** {pulp_pulp_export_href} | Inspect a pulp export
*PulpcoreClient::GroupsApi* | [**add_role**](docs/GroupsApi.md#add_role) | **POST** {group_href}add_role/ | Add a role
*PulpcoreClient::GroupsApi* | [**create**](docs/GroupsApi.md#create) | **POST** /pulp/api/v3/groups/ | Create a group
*PulpcoreClient::GroupsApi* | [**delete**](docs/GroupsApi.md#delete) | **DELETE** {group_href} | Delete a group
*PulpcoreClient::GroupsApi* | [**list**](docs/GroupsApi.md#list) | **GET** /pulp/api/v3/groups/ | List groups
*PulpcoreClient::GroupsApi* | [**list_roles**](docs/GroupsApi.md#list_roles) | **GET** {group_href}list_roles/ | List roles
*PulpcoreClient::GroupsApi* | [**my_permissions**](docs/GroupsApi.md#my_permissions) | **GET** {group_href}my_permissions/ | List user permissions
*PulpcoreClient::GroupsApi* | [**partial_update**](docs/GroupsApi.md#partial_update) | **PATCH** {group_href} | Update a group
*PulpcoreClient::GroupsApi* | [**read**](docs/GroupsApi.md#read) | **GET** {group_href} | Inspect a group
*PulpcoreClient::GroupsApi* | [**remove_role**](docs/GroupsApi.md#remove_role) | **POST** {group_href}remove_role/ | Remove a role
*PulpcoreClient::GroupsApi* | [**update**](docs/GroupsApi.md#update) | **PUT** {group_href} | Update a group
*PulpcoreClient::GroupsRolesApi* | [**create**](docs/GroupsRolesApi.md#create) | **POST** {group_href}roles/ | Create a group role
*PulpcoreClient::GroupsRolesApi* | [**delete**](docs/GroupsRolesApi.md#delete) | **DELETE** {groups_group_role_href} | Delete a group role
*PulpcoreClient::GroupsRolesApi* | [**list**](docs/GroupsRolesApi.md#list) | **GET** {group_href}roles/ | List group roles
*PulpcoreClient::GroupsRolesApi* | [**read**](docs/GroupsRolesApi.md#read) | **GET** {groups_group_role_href} | Inspect a group role
*PulpcoreClient::GroupsUsersApi* | [**create**](docs/GroupsUsersApi.md#create) | **POST** {group_href}users/ | Create an user
*PulpcoreClient::GroupsUsersApi* | [**delete**](docs/GroupsUsersApi.md#delete) | **DELETE** {groups_user_href} | Delete an user
*PulpcoreClient::GroupsUsersApi* | [**list**](docs/GroupsUsersApi.md#list) | **GET** {group_href}users/ | List users
*PulpcoreClient::ImportersPulpApi* | [**create**](docs/ImportersPulpApi.md#create) | **POST** /pulp/api/v3/importers/core/pulp/ | Create a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**delete**](docs/ImportersPulpApi.md#delete) | **DELETE** {pulp_importer_href} | Delete a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**list**](docs/ImportersPulpApi.md#list) | **GET** /pulp/api/v3/importers/core/pulp/ | List pulp importers
*PulpcoreClient::ImportersPulpApi* | [**partial_update**](docs/ImportersPulpApi.md#partial_update) | **PATCH** {pulp_importer_href} | Update a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**read**](docs/ImportersPulpApi.md#read) | **GET** {pulp_importer_href} | Inspect a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**update**](docs/ImportersPulpApi.md#update) | **PUT** {pulp_importer_href} | Update a pulp importer
*PulpcoreClient::ImportersPulpImportCheckApi* | [**pulp_import_check_post**](docs/ImportersPulpImportCheckApi.md#pulp_import_check_post) | **POST** /pulp/api/v3/importers/core/pulp/import-check/ | Validate the parameters to be used for a PulpImport call
*PulpcoreClient::ImportersPulpImportsApi* | [**create**](docs/ImportersPulpImportsApi.md#create) | **POST** {pulp_importer_href}imports/ | Create a pulp import
*PulpcoreClient::ImportersPulpImportsApi* | [**delete**](docs/ImportersPulpImportsApi.md#delete) | **DELETE** {pulp_pulp_import_href} | Delete a pulp import
*PulpcoreClient::ImportersPulpImportsApi* | [**list**](docs/ImportersPulpImportsApi.md#list) | **GET** {pulp_importer_href}imports/ | List pulp imports
*PulpcoreClient::ImportersPulpImportsApi* | [**read**](docs/ImportersPulpImportsApi.md#read) | **GET** {pulp_pulp_import_href} | Inspect a pulp import
*PulpcoreClient::OrphansApi* | [**delete**](docs/OrphansApi.md#delete) | **DELETE** /pulp/api/v3/orphans/ | Delete orphans
*PulpcoreClient::OrphansCleanupApi* | [**cleanup**](docs/OrphansCleanupApi.md#cleanup) | **POST** /pulp/api/v3/orphans/cleanup/ | 
*PulpcoreClient::PublicationsApi* | [**list**](docs/PublicationsApi.md#list) | **GET** /pulp/api/v3/publications/ | List publications
*PulpcoreClient::RemotesApi* | [**list**](docs/RemotesApi.md#list) | **GET** /pulp/api/v3/remotes/ | List remotes
*PulpcoreClient::RepairApi* | [**post**](docs/RepairApi.md#post) | **POST** /pulp/api/v3/repair/ | Repair Artifact Storage
*PulpcoreClient::RepositoriesApi* | [**list**](docs/RepositoriesApi.md#list) | **GET** /pulp/api/v3/repositories/ | List repositories
*PulpcoreClient::RepositoriesReclaimSpaceApi* | [**reclaim**](docs/RepositoriesReclaimSpaceApi.md#reclaim) | **POST** /pulp/api/v3/repositories/reclaim_space/ | 
*PulpcoreClient::RepositoryVersionsApi* | [**list**](docs/RepositoryVersionsApi.md#list) | **GET** /pulp/api/v3/repository_versions/ | List repository versions
*PulpcoreClient::RolesApi* | [**create**](docs/RolesApi.md#create) | **POST** /pulp/api/v3/roles/ | Create a role
*PulpcoreClient::RolesApi* | [**delete**](docs/RolesApi.md#delete) | **DELETE** {role_href} | Delete a role
*PulpcoreClient::RolesApi* | [**list**](docs/RolesApi.md#list) | **GET** /pulp/api/v3/roles/ | List roles
*PulpcoreClient::RolesApi* | [**partial_update**](docs/RolesApi.md#partial_update) | **PATCH** {role_href} | Update a role
*PulpcoreClient::RolesApi* | [**read**](docs/RolesApi.md#read) | **GET** {role_href} | Inspect a role
*PulpcoreClient::RolesApi* | [**update**](docs/RolesApi.md#update) | **PUT** {role_href} | Update a role
*PulpcoreClient::SigningServicesApi* | [**list**](docs/SigningServicesApi.md#list) | **GET** /pulp/api/v3/signing-services/ | List signing services
*PulpcoreClient::SigningServicesApi* | [**read**](docs/SigningServicesApi.md#read) | **GET** {signing_service_href} | Inspect a signing service
*PulpcoreClient::StatusApi* | [**status_read**](docs/StatusApi.md#status_read) | **GET** /pulp/api/v3/status/ | Inspect status of Pulp
*PulpcoreClient::TaskGroupsApi* | [**list**](docs/TaskGroupsApi.md#list) | **GET** /pulp/api/v3/task-groups/ | List task groups
*PulpcoreClient::TaskGroupsApi* | [**read**](docs/TaskGroupsApi.md#read) | **GET** {task_group_href} | Inspect a task group
*PulpcoreClient::TaskSchedulesApi* | [**add_role**](docs/TaskSchedulesApi.md#add_role) | **POST** {task_schedule_href}add_role/ | Add a role
*PulpcoreClient::TaskSchedulesApi* | [**list**](docs/TaskSchedulesApi.md#list) | **GET** /pulp/api/v3/task-schedules/ | List task schedules
*PulpcoreClient::TaskSchedulesApi* | [**list_roles**](docs/TaskSchedulesApi.md#list_roles) | **GET** {task_schedule_href}list_roles/ | List roles
*PulpcoreClient::TaskSchedulesApi* | [**my_permissions**](docs/TaskSchedulesApi.md#my_permissions) | **GET** {task_schedule_href}my_permissions/ | List user permissions
*PulpcoreClient::TaskSchedulesApi* | [**read**](docs/TaskSchedulesApi.md#read) | **GET** {task_schedule_href} | Inspect a task schedule
*PulpcoreClient::TaskSchedulesApi* | [**remove_role**](docs/TaskSchedulesApi.md#remove_role) | **POST** {task_schedule_href}remove_role/ | Remove a role
*PulpcoreClient::TasksApi* | [**add_role**](docs/TasksApi.md#add_role) | **POST** {task_href}add_role/ | Add a role
*PulpcoreClient::TasksApi* | [**delete**](docs/TasksApi.md#delete) | **DELETE** {task_href} | Delete a task
*PulpcoreClient::TasksApi* | [**list**](docs/TasksApi.md#list) | **GET** /pulp/api/v3/tasks/ | List tasks
*PulpcoreClient::TasksApi* | [**list_roles**](docs/TasksApi.md#list_roles) | **GET** {task_href}list_roles/ | List roles
*PulpcoreClient::TasksApi* | [**my_permissions**](docs/TasksApi.md#my_permissions) | **GET** {task_href}my_permissions/ | List user permissions
*PulpcoreClient::TasksApi* | [**purge**](docs/TasksApi.md#purge) | **POST** /pulp/api/v3/tasks/purge/ | Purge Completed Tasks
*PulpcoreClient::TasksApi* | [**read**](docs/TasksApi.md#read) | **GET** {task_href} | Inspect a task
*PulpcoreClient::TasksApi* | [**remove_role**](docs/TasksApi.md#remove_role) | **POST** {task_href}remove_role/ | Remove a role
*PulpcoreClient::TasksApi* | [**tasks_cancel**](docs/TasksApi.md#tasks_cancel) | **PATCH** {task_href} | Cancel a task
*PulpcoreClient::UploadsApi* | [**add_role**](docs/UploadsApi.md#add_role) | **POST** {upload_href}add_role/ | Add a role
*PulpcoreClient::UploadsApi* | [**commit**](docs/UploadsApi.md#commit) | **POST** {upload_href}commit/ | Finish an Upload
*PulpcoreClient::UploadsApi* | [**create**](docs/UploadsApi.md#create) | **POST** /pulp/api/v3/uploads/ | Create an upload
*PulpcoreClient::UploadsApi* | [**delete**](docs/UploadsApi.md#delete) | **DELETE** {upload_href} | Delete an upload
*PulpcoreClient::UploadsApi* | [**list**](docs/UploadsApi.md#list) | **GET** /pulp/api/v3/uploads/ | List uploads
*PulpcoreClient::UploadsApi* | [**list_roles**](docs/UploadsApi.md#list_roles) | **GET** {upload_href}list_roles/ | List roles
*PulpcoreClient::UploadsApi* | [**my_permissions**](docs/UploadsApi.md#my_permissions) | **GET** {upload_href}my_permissions/ | List user permissions
*PulpcoreClient::UploadsApi* | [**read**](docs/UploadsApi.md#read) | **GET** {upload_href} | Inspect an upload
*PulpcoreClient::UploadsApi* | [**remove_role**](docs/UploadsApi.md#remove_role) | **POST** {upload_href}remove_role/ | Remove a role
*PulpcoreClient::UploadsApi* | [**update**](docs/UploadsApi.md#update) | **PUT** {upload_href} | Upload a file chunk
*PulpcoreClient::UpstreamPulpsApi* | [**add_role**](docs/UpstreamPulpsApi.md#add_role) | **POST** {upstream_pulp_href}add_role/ | Add a role
*PulpcoreClient::UpstreamPulpsApi* | [**create**](docs/UpstreamPulpsApi.md#create) | **POST** /pulp/api/v3/upstream-pulps/ | Create an upstream pulp
*PulpcoreClient::UpstreamPulpsApi* | [**delete**](docs/UpstreamPulpsApi.md#delete) | **DELETE** {upstream_pulp_href} | Delete an upstream pulp
*PulpcoreClient::UpstreamPulpsApi* | [**list**](docs/UpstreamPulpsApi.md#list) | **GET** /pulp/api/v3/upstream-pulps/ | List upstream pulps
*PulpcoreClient::UpstreamPulpsApi* | [**list_roles**](docs/UpstreamPulpsApi.md#list_roles) | **GET** {upstream_pulp_href}list_roles/ | List roles
*PulpcoreClient::UpstreamPulpsApi* | [**my_permissions**](docs/UpstreamPulpsApi.md#my_permissions) | **GET** {upstream_pulp_href}my_permissions/ | List user permissions
*PulpcoreClient::UpstreamPulpsApi* | [**partial_update**](docs/UpstreamPulpsApi.md#partial_update) | **PATCH** {upstream_pulp_href} | Update an upstream pulp
*PulpcoreClient::UpstreamPulpsApi* | [**read**](docs/UpstreamPulpsApi.md#read) | **GET** {upstream_pulp_href} | Inspect an upstream pulp
*PulpcoreClient::UpstreamPulpsApi* | [**remove_role**](docs/UpstreamPulpsApi.md#remove_role) | **POST** {upstream_pulp_href}remove_role/ | Remove a role
*PulpcoreClient::UpstreamPulpsApi* | [**replicate**](docs/UpstreamPulpsApi.md#replicate) | **POST** {upstream_pulp_href}replicate/ | Replicate
*PulpcoreClient::UpstreamPulpsApi* | [**update**](docs/UpstreamPulpsApi.md#update) | **PUT** {upstream_pulp_href} | Update an upstream pulp
*PulpcoreClient::UsersApi* | [**create**](docs/UsersApi.md#create) | **POST** /pulp/api/v3/users/ | Create an user
*PulpcoreClient::UsersApi* | [**delete**](docs/UsersApi.md#delete) | **DELETE** {auth_user_href} | Delete an user
*PulpcoreClient::UsersApi* | [**list**](docs/UsersApi.md#list) | **GET** /pulp/api/v3/users/ | List users
*PulpcoreClient::UsersApi* | [**partial_update**](docs/UsersApi.md#partial_update) | **PATCH** {auth_user_href} | Update an user
*PulpcoreClient::UsersApi* | [**read**](docs/UsersApi.md#read) | **GET** {auth_user_href} | Inspect an user
*PulpcoreClient::UsersApi* | [**update**](docs/UsersApi.md#update) | **PUT** {auth_user_href} | Update an user
*PulpcoreClient::UsersRolesApi* | [**create**](docs/UsersRolesApi.md#create) | **POST** {auth_user_href}roles/ | Create an user role
*PulpcoreClient::UsersRolesApi* | [**delete**](docs/UsersRolesApi.md#delete) | **DELETE** {auth_users_user_role_href} | Delete an user role
*PulpcoreClient::UsersRolesApi* | [**list**](docs/UsersRolesApi.md#list) | **GET** {auth_user_href}roles/ | List user roles
*PulpcoreClient::UsersRolesApi* | [**read**](docs/UsersRolesApi.md#read) | **GET** {auth_users_user_role_href} | Inspect an user role
*PulpcoreClient::WorkersApi* | [**list**](docs/WorkersApi.md#list) | **GET** /pulp/api/v3/workers/ | List workers
*PulpcoreClient::WorkersApi* | [**read**](docs/WorkersApi.md#read) | **GET** {worker_href} | Inspect a worker


## Documentation for Models

 - [PulpcoreClient::AccessPolicy](docs/AccessPolicy.md)
 - [PulpcoreClient::AccessPolicyResponse](docs/AccessPolicyResponse.md)
 - [PulpcoreClient::ApiAppStatusResponse](docs/ApiAppStatusResponse.md)
 - [PulpcoreClient::Artifact](docs/Artifact.md)
 - [PulpcoreClient::ArtifactDistributionResponse](docs/ArtifactDistributionResponse.md)
 - [PulpcoreClient::ArtifactResponse](docs/ArtifactResponse.md)
 - [PulpcoreClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpcoreClient::CompositeContentGuard](docs/CompositeContentGuard.md)
 - [PulpcoreClient::CompositeContentGuardResponse](docs/CompositeContentGuardResponse.md)
 - [PulpcoreClient::ContentAppStatusResponse](docs/ContentAppStatusResponse.md)
 - [PulpcoreClient::ContentGuardResponse](docs/ContentGuardResponse.md)
 - [PulpcoreClient::ContentRedirectContentGuard](docs/ContentRedirectContentGuard.md)
 - [PulpcoreClient::ContentRedirectContentGuardResponse](docs/ContentRedirectContentGuardResponse.md)
 - [PulpcoreClient::ContentSettingsResponse](docs/ContentSettingsResponse.md)
 - [PulpcoreClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpcoreClient::DatabaseConnectionResponse](docs/DatabaseConnectionResponse.md)
 - [PulpcoreClient::DistributionResponse](docs/DistributionResponse.md)
 - [PulpcoreClient::Domain](docs/Domain.md)
 - [PulpcoreClient::DomainResponse](docs/DomainResponse.md)
 - [PulpcoreClient::EvaluationResponse](docs/EvaluationResponse.md)
 - [PulpcoreClient::FilesystemExport](docs/FilesystemExport.md)
 - [PulpcoreClient::FilesystemExportResponse](docs/FilesystemExportResponse.md)
 - [PulpcoreClient::FilesystemExporter](docs/FilesystemExporter.md)
 - [PulpcoreClient::FilesystemExporterResponse](docs/FilesystemExporterResponse.md)
 - [PulpcoreClient::Group](docs/Group.md)
 - [PulpcoreClient::GroupProgressReportResponse](docs/GroupProgressReportResponse.md)
 - [PulpcoreClient::GroupResponse](docs/GroupResponse.md)
 - [PulpcoreClient::GroupRole](docs/GroupRole.md)
 - [PulpcoreClient::GroupRoleResponse](docs/GroupRoleResponse.md)
 - [PulpcoreClient::GroupUser](docs/GroupUser.md)
 - [PulpcoreClient::GroupUserResponse](docs/GroupUserResponse.md)
 - [PulpcoreClient::HeaderContentGuard](docs/HeaderContentGuard.md)
 - [PulpcoreClient::HeaderContentGuardResponse](docs/HeaderContentGuardResponse.md)
 - [PulpcoreClient::ImportResponse](docs/ImportResponse.md)
 - [PulpcoreClient::MethodEnum](docs/MethodEnum.md)
 - [PulpcoreClient::MinimalTaskResponse](docs/MinimalTaskResponse.md)
 - [PulpcoreClient::MultipleArtifactContentResponse](docs/MultipleArtifactContentResponse.md)
 - [PulpcoreClient::MyPermissionsResponse](docs/MyPermissionsResponse.md)
 - [PulpcoreClient::NestedRole](docs/NestedRole.md)
 - [PulpcoreClient::NestedRoleResponse](docs/NestedRoleResponse.md)
 - [PulpcoreClient::ObjectRolesResponse](docs/ObjectRolesResponse.md)
 - [PulpcoreClient::OrphansCleanup](docs/OrphansCleanup.md)
 - [PulpcoreClient::PaginatedAccessPolicyResponseList](docs/PaginatedAccessPolicyResponseList.md)
 - [PulpcoreClient::PaginatedArtifactDistributionResponseList](docs/PaginatedArtifactDistributionResponseList.md)
 - [PulpcoreClient::PaginatedArtifactResponseList](docs/PaginatedArtifactResponseList.md)
 - [PulpcoreClient::PaginatedCompositeContentGuardResponseList](docs/PaginatedCompositeContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedContentGuardResponseList](docs/PaginatedContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedContentRedirectContentGuardResponseList](docs/PaginatedContentRedirectContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedDistributionResponseList](docs/PaginatedDistributionResponseList.md)
 - [PulpcoreClient::PaginatedDomainResponseList](docs/PaginatedDomainResponseList.md)
 - [PulpcoreClient::PaginatedFilesystemExportResponseList](docs/PaginatedFilesystemExportResponseList.md)
 - [PulpcoreClient::PaginatedFilesystemExporterResponseList](docs/PaginatedFilesystemExporterResponseList.md)
 - [PulpcoreClient::PaginatedGroupResponseList](docs/PaginatedGroupResponseList.md)
 - [PulpcoreClient::PaginatedGroupRoleResponseList](docs/PaginatedGroupRoleResponseList.md)
 - [PulpcoreClient::PaginatedGroupUserResponseList](docs/PaginatedGroupUserResponseList.md)
 - [PulpcoreClient::PaginatedHeaderContentGuardResponseList](docs/PaginatedHeaderContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedImportResponseList](docs/PaginatedImportResponseList.md)
 - [PulpcoreClient::PaginatedMultipleArtifactContentResponseList](docs/PaginatedMultipleArtifactContentResponseList.md)
 - [PulpcoreClient::PaginatedPublicationResponseList](docs/PaginatedPublicationResponseList.md)
 - [PulpcoreClient::PaginatedPulpExportResponseList](docs/PaginatedPulpExportResponseList.md)
 - [PulpcoreClient::PaginatedPulpExporterResponseList](docs/PaginatedPulpExporterResponseList.md)
 - [PulpcoreClient::PaginatedPulpImporterResponseList](docs/PaginatedPulpImporterResponseList.md)
 - [PulpcoreClient::PaginatedRBACContentGuardResponseList](docs/PaginatedRBACContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedRemoteResponseList](docs/PaginatedRemoteResponseList.md)
 - [PulpcoreClient::PaginatedRepositoryResponseList](docs/PaginatedRepositoryResponseList.md)
 - [PulpcoreClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpcoreClient::PaginatedRoleResponseList](docs/PaginatedRoleResponseList.md)
 - [PulpcoreClient::PaginatedSigningServiceResponseList](docs/PaginatedSigningServiceResponseList.md)
 - [PulpcoreClient::PaginatedTaskGroupResponseList](docs/PaginatedTaskGroupResponseList.md)
 - [PulpcoreClient::PaginatedTaskResponseList](docs/PaginatedTaskResponseList.md)
 - [PulpcoreClient::PaginatedTaskScheduleResponseList](docs/PaginatedTaskScheduleResponseList.md)
 - [PulpcoreClient::PaginatedUploadResponseList](docs/PaginatedUploadResponseList.md)
 - [PulpcoreClient::PaginatedUpstreamPulpResponseList](docs/PaginatedUpstreamPulpResponseList.md)
 - [PulpcoreClient::PaginatedUserResponseList](docs/PaginatedUserResponseList.md)
 - [PulpcoreClient::PaginatedUserRoleResponseList](docs/PaginatedUserRoleResponseList.md)
 - [PulpcoreClient::PaginatedWorkerResponseList](docs/PaginatedWorkerResponseList.md)
 - [PulpcoreClient::PatchedAccessPolicy](docs/PatchedAccessPolicy.md)
 - [PulpcoreClient::PatchedCompositeContentGuard](docs/PatchedCompositeContentGuard.md)
 - [PulpcoreClient::PatchedContentRedirectContentGuard](docs/PatchedContentRedirectContentGuard.md)
 - [PulpcoreClient::PatchedDomain](docs/PatchedDomain.md)
 - [PulpcoreClient::PatchedFilesystemExporter](docs/PatchedFilesystemExporter.md)
 - [PulpcoreClient::PatchedGroup](docs/PatchedGroup.md)
 - [PulpcoreClient::PatchedHeaderContentGuard](docs/PatchedHeaderContentGuard.md)
 - [PulpcoreClient::PatchedPulpExporter](docs/PatchedPulpExporter.md)
 - [PulpcoreClient::PatchedPulpImporter](docs/PatchedPulpImporter.md)
 - [PulpcoreClient::PatchedRBACContentGuard](docs/PatchedRBACContentGuard.md)
 - [PulpcoreClient::PatchedRole](docs/PatchedRole.md)
 - [PulpcoreClient::PatchedTaskCancel](docs/PatchedTaskCancel.md)
 - [PulpcoreClient::PatchedUpstreamPulp](docs/PatchedUpstreamPulp.md)
 - [PulpcoreClient::PatchedUser](docs/PatchedUser.md)
 - [PulpcoreClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpcoreClient::ProgressReportResponse](docs/ProgressReportResponse.md)
 - [PulpcoreClient::PublicationResponse](docs/PublicationResponse.md)
 - [PulpcoreClient::PulpExport](docs/PulpExport.md)
 - [PulpcoreClient::PulpExportResponse](docs/PulpExportResponse.md)
 - [PulpcoreClient::PulpExporter](docs/PulpExporter.md)
 - [PulpcoreClient::PulpExporterResponse](docs/PulpExporterResponse.md)
 - [PulpcoreClient::PulpImport](docs/PulpImport.md)
 - [PulpcoreClient::PulpImportCheck](docs/PulpImportCheck.md)
 - [PulpcoreClient::PulpImportCheckResponse](docs/PulpImportCheckResponse.md)
 - [PulpcoreClient::PulpImporter](docs/PulpImporter.md)
 - [PulpcoreClient::PulpImporterResponse](docs/PulpImporterResponse.md)
 - [PulpcoreClient::Purge](docs/Purge.md)
 - [PulpcoreClient::RBACContentGuard](docs/RBACContentGuard.md)
 - [PulpcoreClient::RBACContentGuardResponse](docs/RBACContentGuardResponse.md)
 - [PulpcoreClient::ReclaimSpace](docs/ReclaimSpace.md)
 - [PulpcoreClient::RedisConnectionResponse](docs/RedisConnectionResponse.md)
 - [PulpcoreClient::RemoteResponse](docs/RemoteResponse.md)
 - [PulpcoreClient::RemoteResponseHiddenFields](docs/RemoteResponseHiddenFields.md)
 - [PulpcoreClient::Repair](docs/Repair.md)
 - [PulpcoreClient::RepositoryResponse](docs/RepositoryResponse.md)
 - [PulpcoreClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpcoreClient::Role](docs/Role.md)
 - [PulpcoreClient::RoleResponse](docs/RoleResponse.md)
 - [PulpcoreClient::SigningServiceResponse](docs/SigningServiceResponse.md)
 - [PulpcoreClient::StatesEnum](docs/StatesEnum.md)
 - [PulpcoreClient::StatusResponse](docs/StatusResponse.md)
 - [PulpcoreClient::StorageClassEnum](docs/StorageClassEnum.md)
 - [PulpcoreClient::StorageResponse](docs/StorageResponse.md)
 - [PulpcoreClient::TaskGroupOperationResponse](docs/TaskGroupOperationResponse.md)
 - [PulpcoreClient::TaskGroupResponse](docs/TaskGroupResponse.md)
 - [PulpcoreClient::TaskResponse](docs/TaskResponse.md)
 - [PulpcoreClient::TaskScheduleResponse](docs/TaskScheduleResponse.md)
 - [PulpcoreClient::Upload](docs/Upload.md)
 - [PulpcoreClient::UploadChunk](docs/UploadChunk.md)
 - [PulpcoreClient::UploadChunkResponse](docs/UploadChunkResponse.md)
 - [PulpcoreClient::UploadCommit](docs/UploadCommit.md)
 - [PulpcoreClient::UploadDetailResponse](docs/UploadDetailResponse.md)
 - [PulpcoreClient::UploadResponse](docs/UploadResponse.md)
 - [PulpcoreClient::UpstreamPulp](docs/UpstreamPulp.md)
 - [PulpcoreClient::UpstreamPulpResponse](docs/UpstreamPulpResponse.md)
 - [PulpcoreClient::User](docs/User.md)
 - [PulpcoreClient::UserGroup](docs/UserGroup.md)
 - [PulpcoreClient::UserGroupResponse](docs/UserGroupResponse.md)
 - [PulpcoreClient::UserResponse](docs/UserResponse.md)
 - [PulpcoreClient::UserRole](docs/UserRole.md)
 - [PulpcoreClient::UserRoleResponse](docs/UserRoleResponse.md)
 - [PulpcoreClient::VersionResponse](docs/VersionResponse.md)
 - [PulpcoreClient::WorkerResponse](docs/WorkerResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

