# PulpcoreClient::RepositoriesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](RepositoriesApi.md#list) | **GET** /pulp/api/v3/repositories/ | List repositories



## list

> PaginatedRepositoryResponseList list(opts)

List repositories

Endpoint to list all repositories.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::RepositoriesApi.new
opts = {
  latest_with_content: 'latest_with_content_example', # String | Content Unit referenced by HREF
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__iexact: 'name__iexact_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__iregex: 'name__iregex_example', # String | Filter results where name matches regex value
  name__istartswith: 'name__istartswith_example', # String | Filter results where name starts with value
  name__regex: 'name__regex_example', # String | Filter results where name matches regex value
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `name` - Name * `-name` - Name (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `description` - Description * `-description` - Description (descending) * `next_version` - Next version * `-next_version` - Next version (descending) * `retain_repo_versions` - Retain repo versions * `-retain_repo_versions` - Retain repo versions (descending) * `user_hidden` - User hidden * `-user_hidden` - User hidden (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_type: 'pulp_type_example', # String | Pulp type  * `file.file` - file.file
  pulp_type__in: ['pulp_type__in_example'], # Array<String> | Multiple values may be separated by commas.  * `file.file` - file.file
  q: 'q_example', # String | 
  remote: 'remote_example', # String | Foreign Key referenced by HREF
  retain_repo_versions: 56, # Integer | Filter results where retain_repo_versions matches value
  retain_repo_versions__gt: 56, # Integer | Filter results where retain_repo_versions is greater than value
  retain_repo_versions__gte: 56, # Integer | Filter results where retain_repo_versions is greater than or equal to value
  retain_repo_versions__isnull: true, # Boolean | Filter results where retain_repo_versions has a null value
  retain_repo_versions__lt: 56, # Integer | Filter results where retain_repo_versions is less than value
  retain_repo_versions__lte: 56, # Integer | Filter results where retain_repo_versions is less than or equal to value
  retain_repo_versions__ne: 56, # Integer | Filter results where retain_repo_versions not equal to value
  retain_repo_versions__range: [56], # Array<Integer> | Filter results where retain_repo_versions is between two comma separated values
  with_content: 'with_content_example', # String | Content Unit referenced by HREF
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List repositories
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling RepositoriesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latest_with_content** | **String**| Content Unit referenced by HREF | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__iexact** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__iregex** | **String**| Filter results where name matches regex value | [optional] 
 **name__istartswith** | **String**| Filter results where name starts with value | [optional] 
 **name__regex** | **String**| Filter results where name matches regex value | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;next_version&#x60; - Next version * &#x60;-next_version&#x60; - Next version (descending) * &#x60;retain_repo_versions&#x60; - Retain repo versions * &#x60;-retain_repo_versions&#x60; - Retain repo versions (descending) * &#x60;user_hidden&#x60; - User hidden * &#x60;-user_hidden&#x60; - User hidden (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_type** | **String**| Pulp type  * &#x60;file.file&#x60; - file.file | [optional] 
 **pulp_type__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas.  * &#x60;file.file&#x60; - file.file | [optional] 
 **q** | **String**|  | [optional] 
 **remote** | [**String**](.md)| Foreign Key referenced by HREF | [optional] 
 **retain_repo_versions** | **Integer**| Filter results where retain_repo_versions matches value | [optional] 
 **retain_repo_versions__gt** | **Integer**| Filter results where retain_repo_versions is greater than value | [optional] 
 **retain_repo_versions__gte** | **Integer**| Filter results where retain_repo_versions is greater than or equal to value | [optional] 
 **retain_repo_versions__isnull** | **Boolean**| Filter results where retain_repo_versions has a null value | [optional] 
 **retain_repo_versions__lt** | **Integer**| Filter results where retain_repo_versions is less than value | [optional] 
 **retain_repo_versions__lte** | **Integer**| Filter results where retain_repo_versions is less than or equal to value | [optional] 
 **retain_repo_versions__ne** | **Integer**| Filter results where retain_repo_versions not equal to value | [optional] 
 **retain_repo_versions__range** | [**Array&lt;Integer&gt;**](Integer.md)| Filter results where retain_repo_versions is between two comma separated values | [optional] 
 **with_content** | **String**| Content Unit referenced by HREF | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedRepositoryResponseList**](PaginatedRepositoryResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

