# PulpcoreClient::UsersApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](UsersApi.md#create) | **POST** /pulp/api/v3/users/ | Create an user
[**delete**](UsersApi.md#delete) | **DELETE** {auth_user_href} | Delete an user
[**list**](UsersApi.md#list) | **GET** /pulp/api/v3/users/ | List users
[**partial_update**](UsersApi.md#partial_update) | **PATCH** {auth_user_href} | Update an user
[**read**](UsersApi.md#read) | **GET** {auth_user_href} | Inspect an user
[**update**](UsersApi.md#update) | **PUT** {auth_user_href} | Update an user



## create

> UserResponse create(user)

Create an user

ViewSet for User.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::UsersApi.new
user = PulpcoreClient::User.new # User | 

begin
  #Create an user
  result = api_instance.create(user)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling UsersApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user** | [**User**](User.md)|  | 

### Return type

[**UserResponse**](UserResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(auth_user_href)

Delete an user

ViewSet for User.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::UsersApi.new
auth_user_href = 'auth_user_href_example' # String | 

begin
  #Delete an user
  api_instance.delete(auth_user_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling UsersApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_user_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedUserResponseList list(opts)

List users

ViewSet for User.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::UsersApi.new
opts = {
  email: 'email_example', # String | Filter results where email matches value
  email__contains: 'email__contains_example', # String | Filter results where email contains value
  email__icontains: 'email__icontains_example', # String | Filter results where email contains value
  email__iexact: 'email__iexact_example', # String | Filter results where email matches value
  email__in: ['email__in_example'], # Array<String> | Filter results where email is in a comma-separated list of values
  first_name: 'first_name_example', # String | Filter results where first_name matches value
  first_name__contains: 'first_name__contains_example', # String | Filter results where first_name contains value
  first_name__icontains: 'first_name__icontains_example', # String | Filter results where first_name contains value
  first_name__iexact: 'first_name__iexact_example', # String | Filter results where first_name matches value
  first_name__in: ['first_name__in_example'], # Array<String> | Filter results where first_name is in a comma-separated list of values
  is_active: true, # Boolean | Filter results where is_active matches value
  is_staff: true, # Boolean | Filter results where is_staff matches value
  last_name: 'last_name_example', # String | Filter results where last_name matches value
  last_name__contains: 'last_name__contains_example', # String | Filter results where last_name contains value
  last_name__icontains: 'last_name__icontains_example', # String | Filter results where last_name contains value
  last_name__iexact: 'last_name__iexact_example', # String | Filter results where last_name matches value
  last_name__in: ['last_name__in_example'], # Array<String> | Filter results where last_name is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `id` - Id * `-id` - Id (descending) * `password` - Password * `-password` - Password (descending) * `last_login` - Last login * `-last_login` - Last login (descending) * `is_superuser` - Is superuser * `-is_superuser` - Is superuser (descending) * `username` - Username * `-username` - Username (descending) * `first_name` - First name * `-first_name` - First name (descending) * `last_name` - Last name * `-last_name` - Last name (descending) * `email` - Email * `-email` - Email (descending) * `is_staff` - Is staff * `-is_staff` - Is staff (descending) * `is_active` - Is active * `-is_active` - Is active (descending) * `date_joined` - Date joined * `-date_joined` - Date joined (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  username: 'username_example', # String | Filter results where username matches value
  username__contains: 'username__contains_example', # String | Filter results where username contains value
  username__icontains: 'username__icontains_example', # String | Filter results where username contains value
  username__iexact: 'username__iexact_example', # String | Filter results where username matches value
  username__in: ['username__in_example'], # Array<String> | Filter results where username is in a comma-separated list of values
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List users
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling UsersApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **email** | **String**| Filter results where email matches value | [optional] 
 **email__contains** | **String**| Filter results where email contains value | [optional] 
 **email__icontains** | **String**| Filter results where email contains value | [optional] 
 **email__iexact** | **String**| Filter results where email matches value | [optional] 
 **email__in** | [**Array&lt;String&gt;**](String.md)| Filter results where email is in a comma-separated list of values | [optional] 
 **first_name** | **String**| Filter results where first_name matches value | [optional] 
 **first_name__contains** | **String**| Filter results where first_name contains value | [optional] 
 **first_name__icontains** | **String**| Filter results where first_name contains value | [optional] 
 **first_name__iexact** | **String**| Filter results where first_name matches value | [optional] 
 **first_name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where first_name is in a comma-separated list of values | [optional] 
 **is_active** | **Boolean**| Filter results where is_active matches value | [optional] 
 **is_staff** | **Boolean**| Filter results where is_staff matches value | [optional] 
 **last_name** | **String**| Filter results where last_name matches value | [optional] 
 **last_name__contains** | **String**| Filter results where last_name contains value | [optional] 
 **last_name__icontains** | **String**| Filter results where last_name contains value | [optional] 
 **last_name__iexact** | **String**| Filter results where last_name matches value | [optional] 
 **last_name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where last_name is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;id&#x60; - Id * &#x60;-id&#x60; - Id (descending) * &#x60;password&#x60; - Password * &#x60;-password&#x60; - Password (descending) * &#x60;last_login&#x60; - Last login * &#x60;-last_login&#x60; - Last login (descending) * &#x60;is_superuser&#x60; - Is superuser * &#x60;-is_superuser&#x60; - Is superuser (descending) * &#x60;username&#x60; - Username * &#x60;-username&#x60; - Username (descending) * &#x60;first_name&#x60; - First name * &#x60;-first_name&#x60; - First name (descending) * &#x60;last_name&#x60; - Last name * &#x60;-last_name&#x60; - Last name (descending) * &#x60;email&#x60; - Email * &#x60;-email&#x60; - Email (descending) * &#x60;is_staff&#x60; - Is staff * &#x60;-is_staff&#x60; - Is staff (descending) * &#x60;is_active&#x60; - Is active * &#x60;-is_active&#x60; - Is active (descending) * &#x60;date_joined&#x60; - Date joined * &#x60;-date_joined&#x60; - Date joined (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **username** | **String**| Filter results where username matches value | [optional] 
 **username__contains** | **String**| Filter results where username contains value | [optional] 
 **username__icontains** | **String**| Filter results where username contains value | [optional] 
 **username__iexact** | **String**| Filter results where username matches value | [optional] 
 **username__in** | [**Array&lt;String&gt;**](String.md)| Filter results where username is in a comma-separated list of values | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedUserResponseList**](PaginatedUserResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> UserResponse partial_update(auth_user_href, patched_user)

Update an user

ViewSet for User.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::UsersApi.new
auth_user_href = 'auth_user_href_example' # String | 
patched_user = PulpcoreClient::PatchedUser.new # PatchedUser | 

begin
  #Update an user
  result = api_instance.partial_update(auth_user_href, patched_user)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling UsersApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_user_href** | **String**|  | 
 **patched_user** | [**PatchedUser**](PatchedUser.md)|  | 

### Return type

[**UserResponse**](UserResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> UserResponse read(auth_user_href, opts)

Inspect an user

ViewSet for User.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::UsersApi.new
auth_user_href = 'auth_user_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an user
  result = api_instance.read(auth_user_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling UsersApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_user_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**UserResponse**](UserResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> UserResponse update(auth_user_href, user)

Update an user

ViewSet for User.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::UsersApi.new
auth_user_href = 'auth_user_href_example' # String | 
user = PulpcoreClient::User.new # User | 

begin
  #Update an user
  result = api_instance.update(auth_user_href, user)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling UsersApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_user_href** | **String**|  | 
 **user** | [**User**](User.md)|  | 

### Return type

[**UserResponse**](UserResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

